@@ -1,6 +1,6 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013 Red Hat, Inc.
+# Copyright (C) 2013-2015 Red Hat, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,7 +20,6 @@
 
 
 import gettext
-_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-dwh')
 
 
 from otopi import constants as otopicons
@@ -36,6 +35,10 @@ from ovirt_engine_setup.dwh import constants as odwhcons
 from ovirt_engine_setup.engine_common import database
 
 
+def _(m):
+    return gettext.dgettext(message=m, domain='ovirt-engine-dwh')
+
+
 @util.export
 class Plugin(plugin.PluginBase):
     """Connection plugin."""
@@ -52,11 +55,6 @@ class Plugin(plugin.PluginBase):
         ].append(
             odwhcons.DBEnv.PASSWORD
         )
-        self.environment[
-            otopicons.CoreEnv.LOG_FILTER_KEYS
-        ].append(
-            odwhcons.EngineDBEnv.PASSWORD
-        )
 
     @plugin.event(
         stage=plugin.Stages.STAGE_INIT,
@@ -90,6 +88,18 @@ class Plugin(plugin.PluginBase):
             odwhcons.DBEnv.DATABASE,
             None
         )
+        self.environment.setdefault(
+            odwhcons.DBEnv.DUMPER,
+            odwhcons.Defaults.DEFAULT_DB_DUMPER
+        )
+        self.environment.setdefault(
+            odwhcons.DBEnv.FILTER,
+            odwhcons.Defaults.DEFAULT_DB_FILTER
+        )
+        self.environment.setdefault(
+            odwhcons.DBEnv.RESTORE_JOBS,
+            odwhcons.Defaults.DEFAULT_DB_RESTORE_JOBS
+        )
 
         # TODO: probably we can add helper function within database.py to get
         # dbkeys and set all to none, instead of duplicating this.
@@ -98,39 +108,6 @@ class Plugin(plugin.PluginBase):
         self.environment[odwhcons.DBEnv.STATEMENT] = None
         self.environment[odwhcons.DBEnv.NEW_DATABASE] = True
 
-        self.environment.setdefault(
-            odwhcons.EngineDBEnv.HOST,
-            None
-        )
-        self.environment.setdefault(
-            odwhcons.EngineDBEnv.PORT,
-            None
-        )
-        self.environment.setdefault(
-            odwhcons.EngineDBEnv.SECURED,
-            None
-        )
-        self.environment.setdefault(
-            odwhcons.EngineDBEnv.SECURED_HOST_VALIDATION,
-            None
-        )
-        self.environment.setdefault(
-            odwhcons.EngineDBEnv.USER,
-            None
-        )
-        self.environment.setdefault(
-            odwhcons.EngineDBEnv.PASSWORD,
-            None
-        )
-        self.environment.setdefault(
-            odwhcons.EngineDBEnv.DATABASE,
-            None
-        )
-
-        self.environment[odwhcons.EngineDBEnv.CONNECTION] = None
-        self.environment[odwhcons.EngineDBEnv.STATEMENT] = None
-        self.environment[odwhcons.EngineDBEnv.NEW_DATABASE] = True
-
     @plugin.event(
         stage=plugin.Stages.STAGE_SETUP,
     )
